#ifndef CEPROG_H
#define CEPROG_H
/*
 * Eprom Programmer
 *
 * Copyright 1996-2007 netFluid Technology Ltd
 * http://www.nfluid.co.uk
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 *
 * $Revision: 1.2 $  $Date: 2007/02/15 19:05:22 $
 * 
 * --------------------------------------------------------------------------
 */
#include <linux/ppdev.h>
#include <linux/parport.h>
#include <sys/io.h>
#include <sys/ioctl.h>

#define VERSION         "1.2a"
#define VERSION_YEAR    "2007"

#define PPORT       0x378
#define STRING_MAX  64

struct cfrob {
   unsigned char mask;
   unsigned char val;
};
    
#define PIN_C0 PARPORT_CONTROL_STROBE /* /C0 */
#define PIN_C1 PARPORT_CONTROL_AUTOFD /* /C1 */
#define PIN_C2 PARPORT_CONTROL_INIT   /*  C2 */
#define PIN_C3 PARPORT_CONTROL_SELECT /* /C3 */

typedef enum { EPRG_ADDR_CLOCK = PIN_C0, /* Active LOW  */
               EPRG_REG_LATCH  = PIN_C1, /* Active HIGH */
               EPRG_EPROM_OE   = PIN_C2, /* Active LOW  */
               EPRG_EPROM_PROG = PIN_C3  /* Active LOW  */
            } parallelPortCtrl;

typedef enum { EPRG_LATCH_VPP_PROG    = 1<<8,  /* Active LOW  */
               EPRG_LATCH_VCC_625     = 1<<9,  /* Active LOW  */
               EPRG_LATCH_CEPRG       = 1<<10, /* Active HIGH */
               EPRG_LATCH_CE          = 1<<11, /* Active LOW  */
               EPRG_LATCH_CLOCK_RESET = 1<<15  /* Active HIGH */
            } controlRegister;

typedef enum { PORT_DIR_READ    = 1,
               PORT_DIR_WRITE   = 2 } PortDirection;

typedef enum { MODE_READ        = 0, 
               MODE_BLANK       = 1,
               MODE_STD_WRITE   = 2,
               MODE_QUICK_WRITE = 3, 
               MODE_VERIFY      = 4 } ProgrammerMode;

typedef enum { VPP = 1, VSS, VCC, A0, A1, A2, A3, A4, A5, A6, A7, A8, A9, A10, A11, A12, A13, A14, A15, Q0, Q1, Q2, Q3, Q4, Q5, Q6, Q7, CE, OE, PROG } PinDesignation;

typedef struct {
    char *device;
    int  size;
    char *manufacturer;
    int  pins;
    double vpp;
    double vcc;
    long   pulse_us;
    long   max_pulses;
    long   overprogram;
    PinDesignation designation[64];
    PinDesignation progpin;
} Device;

/* ------------------------------------------------------------------------- */
#endif
