/*
 * Eprom Programmer
 *
 * Copyright 1996-2007 netFluid Technology Ltd
 * http://www.nfluid.co.uk
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 *
 * $Revision: 1.2 $  $Date: 2007/02/15 21:25:01 $
 * 
 * --------------------------------------------------------------------------
 */

#include <stdio.h>
#include <stdlib.h>
#include <sys/time.h>
#include <time.h>

#include "ceprog.h"

static double delayOverhead = 1;

extern int verbose;
extern int vindent;


/* ------------------------------------------------------------------------- */

void
micro_sleep( int usec )
{
    int i = 0;
    int limit = usec * delayOverhead; /* Adjust based on calibration */

    if( verbose == 3 ) printf( "%*s(sleep %d us)\n", vindent, "", usec );

    for( i = 0; i < limit; i++ ) inb(PPORT+0); /* Approx 1us delay */
}

/* ------------------------------------------------------------------------- */

void
calibrate_delay_loop()
{
    long total = 0;
    int      i = 0;
    int      j = 0;
    double  oh = 0;
    double  ohs = 0;
    long    elapse = 0;
    struct timeval before;
    struct timeval now;

    printf( "Calibrating" );
    for( j = 0; j < 10; j++ )
    {
        printf( "." );
        fflush(stdout);
        delayOverhead = 1;

        for( i = 10; i <= 5000; i+=60 )
        {
            gettimeofday(&before,NULL);
            micro_sleep(i);
            gettimeofday(&now,NULL);

            total += i;
            elapse = ((now.tv_sec-before.tv_sec)*1000000)+(now.tv_usec-before.tv_usec);
            oh    += elapse;
        }
        ohs += total / oh;
    }
    delayOverhead = ohs / (double)j;
    printf( "done\n\n" );
}

/* ------------------------------------------------------------------------- */
/* end */
